==> quarkus-kubernetes-deployment-2.16.0.Final-sources.jar: io/quarkus/kubernetes/deployment/ProbeConfig$$accessor.java <==
package io.quarkus.kubernetes.deployment;
public final class ProbeConfig$$accessor {
    private ProbeConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_httpActionPath(Object __instance) {
        return ((ProbeConfig)__instance).httpActionPath;
    }
    @SuppressWarnings("unchecked")
    public static void set_httpActionPath(Object __instance, Object httpActionPath) {
        ((ProbeConfig)__instance).httpActionPath = (java.util.Optional<String>)httpActionPath;
    }
    @SuppressWarnings("unchecked")
    public static Object get_execAction(Object __instance) {
        return ((ProbeConfig)__instance).execAction;
    }
    @SuppressWarnings("unchecked")
    public static void set_execAction(Object __instance, Object execAction) {
        ((ProbeConfig)__instance).execAction = (java.util.Optional<String>)execAction;
    }
    @SuppressWarnings("unchecked")
    public static Object get_tcpSocketAction(Object __instance) {
        return ((ProbeConfig)__instance).tcpSocketAction;
    }
    @SuppressWarnings("unchecked")
    public static void set_tcpSocketAction(Object __instance, Object tcpSocketAction) {
        ((ProbeConfig)__instance).tcpSocketAction = (java.util.Optional<String>)tcpSocketAction;
    }
    @SuppressWarnings("unchecked")
    public static Object get_initialDelay(Object __instance) {
        return ((ProbeConfig)__instance).initialDelay;
    }
    @SuppressWarnings("unchecked")
    public static void set_initialDelay(Object __instance, Object initialDelay) {
        ((ProbeConfig)__instance).initialDelay = (java.time.Duration)initialDelay;
    }
    @SuppressWarnings("unchecked")
    public static Object get_period(Object __instance) {
        return ((ProbeConfig)__instance).period;
    }
    @SuppressWarnings("unchecked")
    public static void set_period(Object __instance, Object period) {
        ((ProbeConfig)__instance).period = (java.time.Duration)period;
    }
    @SuppressWarnings("unchecked")
    public static Object get_timeout(Object __instance) {
        return ((ProbeConfig)__instance).timeout;
    }
    @SuppressWarnings("unchecked")
    public static void set_timeout(Object __instance, Object timeout) {
        ((ProbeConfig)__instance).timeout = (java.time.Duration)timeout;
    }
    @SuppressWarnings("unchecked")
    public static Object get_successThreshold(Object __instance) {
        return ((ProbeConfig)__instance).successThreshold;
    }
    @SuppressWarnings("unchecked")
    public static void set_successThreshold(Object __instance, Object successThreshold) {
        ((ProbeConfig)__instance).successThreshold = (Integer)successThreshold;
    }
    @SuppressWarnings("unchecked")
    public static Object get_failureThreshold(Object __instance) {
        return ((ProbeConfig)__instance).failureThreshold;
    }
    @SuppressWarnings("unchecked")
    public static void set_failureThreshold(Object __instance, Object failureThreshold) {
        ((ProbeConfig)__instance).failureThreshold = (Integer)failureThreshold;
    }
}

==> quarkus-kubernetes-deployment-3.2.0.Final-sources.jar: io/quarkus/kubernetes/deployment/ProbeConfig$$accessor.java <==
package io.quarkus.kubernetes.deployment;
public final class ProbeConfig$$accessor {
    private ProbeConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_httpActionPort(Object __instance) {
        return ((ProbeConfig)__instance).httpActionPort;
    }
    @SuppressWarnings("unchecked")
    public static void set_httpActionPort(Object __instance, Object httpActionPort) {
        ((ProbeConfig)__instance).httpActionPort = (java.util.Optional<Integer>)httpActionPort;
    }
    @SuppressWarnings("unchecked")
    public static Object get_httpActionPortName(Object __instance) {
        return ((ProbeConfig)__instance).httpActionPortName;
    }
    @SuppressWarnings("unchecked")
    public static void set_httpActionPortName(Object __instance, Object httpActionPortName) {
        ((ProbeConfig)__instance).httpActionPortName = (java.util.Optional<String>)httpActionPortName;
    }
    @SuppressWarnings("unchecked")
    public static Object get_httpActionPath(Object __instance) {
        return ((ProbeConfig)__instance).httpActionPath;
    }
    @SuppressWarnings("unchecked")
    public static void set_httpActionPath(Object __instance, Object httpActionPath) {
        ((ProbeConfig)__instance).httpActionPath = (java.util.Optional<String>)httpActionPath;
    }
    @SuppressWarnings("unchecked")
    public static Object get_httpActionScheme(Object __instance) {
        return ((ProbeConfig)__instance).httpActionScheme;
    }
    @SuppressWarnings("unchecked")
    public static void set_httpActionScheme(Object __instance, Object httpActionScheme) {
        ((ProbeConfig)__instance).httpActionScheme = (java.util.Optional<String>)httpActionScheme;
    }
    @SuppressWarnings("unchecked")
    public static Object get_execAction(Object __instance) {
        return ((ProbeConfig)__instance).execAction;
    }
    @SuppressWarnings("unchecked")
    public static void set_execAction(Object __instance, Object execAction) {
        ((ProbeConfig)__instance).execAction = (java.util.Optional<String>)execAction;
    }
    @SuppressWarnings("unchecked")
    public static Object get_tcpSocketAction(Object __instance) {
        return ((ProbeConfig)__instance).tcpSocketAction;
    }
    @SuppressWarnings("unchecked")
    public static void set_tcpSocketAction(Object __instance, Object tcpSocketAction) {
        ((ProbeConfig)__instance).tcpSocketAction = (java.util.Optional<String>)tcpSocketAction;
    }
    @SuppressWarnings("unchecked")
    public static Object get_grpcAction(Object __instance) {
        return ((ProbeConfig)__instance).grpcAction;
    }
    @SuppressWarnings("unchecked")
    public static void set_grpcAction(Object __instance, Object grpcAction) {
        ((ProbeConfig)__instance).grpcAction = (java.util.Optional<String>)grpcAction;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_grpcActionEnabled(Object __instance) {
        return ((ProbeConfig)__instance).grpcActionEnabled;
    }
    @SuppressWarnings("unchecked")
    public static void set_grpcActionEnabled(Object __instance, boolean grpcActionEnabled) {
        ((ProbeConfig)__instance).grpcActionEnabled = grpcActionEnabled;
    }
    @SuppressWarnings("unchecked")
    public static Object get_initialDelay(Object __instance) {
        return ((ProbeConfig)__instance).initialDelay;
    }
    @SuppressWarnings("unchecked")
    public static void set_initialDelay(Object __instance, Object initialDelay) {
        ((ProbeConfig)__instance).initialDelay = (java.time.Duration)initialDelay;
    }
    @SuppressWarnings("unchecked")
    public static Object get_period(Object __instance) {
        return ((ProbeConfig)__instance).period;
    }
    @SuppressWarnings("unchecked")
    public static void set_period(Object __instance, Object period) {
        ((ProbeConfig)__instance).period = (java.time.Duration)period;
    }
    @SuppressWarnings("unchecked")
    public static Object get_timeout(Object __instance) {
        return ((ProbeConfig)__instance).timeout;
    }
    @SuppressWarnings("unchecked")
    public static void set_timeout(Object __instance, Object timeout) {
        ((ProbeConfig)__instance).timeout = (java.time.Duration)timeout;
    }
    @SuppressWarnings("unchecked")
    public static Object get_successThreshold(Object __instance) {
        return ((ProbeConfig)__instance).successThreshold;
    }
    @SuppressWarnings("unchecked")
    public static void set_successThreshold(Object __instance, Object successThreshold) {
        ((ProbeConfig)__instance).successThreshold = (Integer)successThreshold;
    }
    @SuppressWarnings("unchecked")
    public static Object get_failureThreshold(Object __instance) {
        return ((ProbeConfig)__instance).failureThreshold;
    }
    @SuppressWarnings("unchecked")
    public static void set_failureThreshold(Object __instance, Object failureThreshold) {
        ((ProbeConfig)__instance).failureThreshold = (Integer)failureThreshold;
    }
}
